==> pw-iso20022-SRU2022-9.3.1-sources.jar: com/prowidesoftware/swift/model/mx/dic/FundCashOutBreakdown1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Breakdown of cash movements out of a fund as a result of investment funds transactions, eg, redemptions or switch-out.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FundCashOutBreakdown1", propOrder = {
    "amt",
    "unitsNb",
    "newAmtInd",
    "invstmtFndTxOutTpDtls",
    "orgnlOrdrQtyDtls",
    "comssnDtls"
})
public class FundCashOutBreakdown1 {

    @XmlElement(name = "Amt")
    protected ActiveOrHistoricCurrencyAndAmount amt;
    @XmlElement(name = "UnitsNb")
    protected FinancialInstrumentQuantity1 unitsNb;
    @XmlElement(name = "NewAmtInd")
    protected Boolean newAmtInd;
    @XmlElement(name = "InvstmtFndTxOutTpDtls")
    protected InvestmentFundTransactionOutType1 invstmtFndTxOutTpDtls;
    @XmlElement(name = "OrgnlOrdrQtyDtls")
    protected OriginalOrderQuantityType1 orgnlOrdrQtyDtls;
    @XmlElement(name = "ComssnDtls")
    protected List<Commission4> comssnDtls;

    /**
     * Gets the value of the amt property.
     * 
     * @return
     *     possible object is
     *     {@link ActiveOrHistoricCurrencyAndAmount }
     *     
     */
    public ActiveOrHistoricCurrencyAndAmount getAmt() {
        return amt;
    }

    /**
     * Sets the value of the amt property.
     * 
     * @param value
     *     allowed object is
     *     {@link ActiveOrHistoricCurrencyAndAmount }
     *     
     */
    public FundCashOutBreakdown1 setAmt(ActiveOrHistoricCurrencyAndAmount value) {
        this.amt = value;
        return this;
    }

    /**
     * Gets the value of the unitsNb property.
     * 
     * @return
     *     possible object is
     *     {@link FinancialInstrumentQuantity1 }
     *     
     */
    public FinancialInstrumentQuantity1 getUnitsNb() {
        return unitsNb;
    }

    /**
     * Sets the value of the unitsNb property.
     * 
     * @param value
     *     allowed object is
     *     {@link FinancialInstrumentQuantity1 }
     *     
     */
    public FundCashOutBreakdown1 setUnitsNb(FinancialInstrumentQuantity1 value) {
        this.unitsNb = value;
        return this;
    }

    /**
     * Gets the value of the newAmtInd property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isNewAmtInd() {
        return newAmtInd;
    }

    /**
     * Sets the value of the newAmtInd property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public FundCashOutBreakdown1 setNewAmtInd(Boolean value) {
        this.newAmtInd = value;
        return this;
    }

    /**
     * Gets the value of the invstmtFndTxOutTpDtls property.
     * 
     * @return
     *     possible object is
     *     {@link InvestmentFundTransactionOutType1 }
     *     
     */
    public InvestmentFundTransactionOutType1 getInvstmtFndTxOutTpDtls() {
        return invstmtFndTxOutTpDtls;
    }

    /**
     * Sets the value of the invstmtFndTxOutTpDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link InvestmentFundTransactionOutType1 }
     *     
     */
    public FundCashOutBreakdown1 setInvstmtFndTxOutTpDtls(InvestmentFundTransactionOutType1 value) {
        this.invstmtFndTxOutTpDtls = value;
        return this;
    }

    /**
     * Gets the value of the orgnlOrdrQtyDtls property.
     * 
     * @return
     *     possible object is
     *     {@link OriginalOrderQuantityType1 }
     *     
     */
    public OriginalOrderQuantityType1 getOrgnlOrdrQtyDtls() {
        return orgnlOrdrQtyDtls;
    }

    /**
     * Sets the value of the orgnlOrdrQtyDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link OriginalOrderQuantityType1 }
     *     
     */
    public FundCashOutBreakdown1 setOrgnlOrdrQtyDtls(OriginalOrderQuantityType1 value) {
        this.orgnlOrdrQtyDtls = value;
        return this;
    }

    /**
     * Gets the value of the comssnDtls property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the comssnDtls property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getComssnDtls().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Commission4 }
     * 
     * 
     */
    public List<Commission4> getComssnDtls() {
        if (comssnDtls == null) {
            comssnDtls = new ArrayList<Commission4>();
        }
        return this.comssnDtls;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

    /**
     * Adds a new item to the comssnDtls list.
     * @see #getComssnDtls()
     * 
     */
    public FundCashOutBreakdown1 addComssnDtls(Commission4 comssnDtls) {
        getComssnDtls().add(comssnDtls);
        return this;
    }

}

==> pw-iso20022-SRU2025-10.3.3-sources.jar: com/prowidesoftware/swift/model/mx/dic/FundCashOutBreakdown1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Breakdown of cash movements out of a fund as a result of investment funds transactions, eg, redemptions or switch-out.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FundCashOutBreakdown1", propOrder = {
    "amt",
    "unitsNb",
    "newAmtInd",
    "invstmtFndTxOutTpDtls",
    "orgnlOrdrQtyDtls",
    "comssnDtls"
})
public class FundCashOutBreakdown1 {

    @XmlElement(name = "Amt")
    protected ActiveOrHistoricCurrencyAndAmount amt;
    @XmlElement(name = "UnitsNb")
    protected FinancialInstrumentQuantity1 unitsNb;
    @XmlElement(name = "NewAmtInd")
    protected Boolean newAmtInd;
    @XmlElement(name = "InvstmtFndTxOutTpDtls")
    protected InvestmentFundTransactionOutType1 invstmtFndTxOutTpDtls;
    @XmlElement(name = "OrgnlOrdrQtyDtls")
    protected OriginalOrderQuantityType1 orgnlOrdrQtyDtls;
    @XmlElement(name = "ComssnDtls")
    protected List<Commission4> comssnDtls;

    /**
     * Gets the value of the amt property.
     * 
     * @return
     *     possible object is
     *     {@link ActiveOrHistoricCurrencyAndAmount }
     *     
     */
    public ActiveOrHistoricCurrencyAndAmount getAmt() {
        return amt;
    }

    /**
     * Sets the value of the amt property.
     * 
     * @param value
     *     allowed object is
     *     {@link ActiveOrHistoricCurrencyAndAmount }
     *     
     */
    public FundCashOutBreakdown1 setAmt(ActiveOrHistoricCurrencyAndAmount value) {
        this.amt = value;
        return this;
    }

    /**
     * Gets the value of the unitsNb property.
     * 
     * @return
     *     possible object is
     *     {@link FinancialInstrumentQuantity1 }
     *     
     */
    public FinancialInstrumentQuantity1 getUnitsNb() {
        return unitsNb;
    }

    /**
     * Sets the value of the unitsNb property.
     * 
     * @param value
     *     allowed object is
     *     {@link FinancialInstrumentQuantity1 }
     *     
     */
    public FundCashOutBreakdown1 setUnitsNb(FinancialInstrumentQuantity1 value) {
        this.unitsNb = value;
        return this;
    }

    /**
     * Gets the value of the newAmtInd property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isNewAmtInd() {
        return newAmtInd;
    }

    /**
     * Sets the value of the newAmtInd property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public FundCashOutBreakdown1 setNewAmtInd(Boolean value) {
        this.newAmtInd = value;
        return this;
    }

    /**
     * Gets the value of the invstmtFndTxOutTpDtls property.
     * 
     * @return
     *     possible object is
     *     {@link InvestmentFundTransactionOutType1 }
     *     
     */
    public InvestmentFundTransactionOutType1 getInvstmtFndTxOutTpDtls() {
        return invstmtFndTxOutTpDtls;
    }

    /**
     * Sets the value of the invstmtFndTxOutTpDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link InvestmentFundTransactionOutType1 }
     *     
     */
    public FundCashOutBreakdown1 setInvstmtFndTxOutTpDtls(InvestmentFundTransactionOutType1 value) {
        this.invstmtFndTxOutTpDtls = value;
        return this;
    }

    /**
     * Gets the value of the orgnlOrdrQtyDtls property.
     * 
     * @return
     *     possible object is
     *     {@link OriginalOrderQuantityType1 }
     *     
     */
    public OriginalOrderQuantityType1 getOrgnlOrdrQtyDtls() {
        return orgnlOrdrQtyDtls;
    }

    /**
     * Sets the value of the orgnlOrdrQtyDtls property.
     * 
     * @param value
     *     allowed object is
     *     {@link OriginalOrderQuantityType1 }
     *     
     */
    public FundCashOutBreakdown1 setOrgnlOrdrQtyDtls(OriginalOrderQuantityType1 value) {
        this.orgnlOrdrQtyDtls = value;
        return this;
    }

    /**
     * Gets the value of the comssnDtls property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the comssnDtls property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getComssnDtls().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Commission4 }
     * 
     * 
     * @return
     *     The value of the comssnDtls property.
     */
    public List<Commission4> getComssnDtls() {
        if (comssnDtls == null) {
            comssnDtls = new ArrayList<>();
        }
        return this.comssnDtls;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

    /**
     * Adds a new item to the comssnDtls list.
     * @see #getComssnDtls()
     * 
     */
    public FundCashOutBreakdown1 addComssnDtls(Commission4 comssnDtls) {
        getComssnDtls().add(comssnDtls);
        return this;
    }

}
